Mail.ru - velruse.providers.mailru — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Mail.ru - `velruse.providers.mailru`

The Mail.ru provider combines authentication with OAuth 2.0 authorization. It requires either a Mail.ru Site or a Mail.ru Application (the platform makes distinctions between Sites and Applications) to have been created to use.

Mail.ru Links (Russian):

- Register a new Mail.ru Site
- Register a new Mail.ru Application
- Mail.ru OAuth Developer Guide
- Mail.ru API Guide

## Settings

`consumer_key`
  Mail.ru Site/Application ID
`consumer_secret`
  Mail.ru Secret Key

## POST Parameters

Complete Example:

    <form action="/velruse/mailru/login" method="post">
        <input type="submit" value="Login with Mail.ru" />
    </form>

## Pyramid API

Mail.ru Authentication Views

You may see developer docs on http://api.mail.ru/docs/guides/oauth/

class `MailRuAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.AuthenticationComplete`

  MailRu auth complete

`includeme`(config)

`add_mailru_login`(config, consumer_key, consumer_secret, scope=None, login_path='/login/mailru', callback_path='/login/mailru/callback', name='mailru')

  Add a MailRu login provider to the application.

`add_mailru_login_from_settings`(config, prefix='velruse.mailru.')

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »